==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ImageColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ImageColumnDescription } from "./ImageColumnDescription";
/**
 * @hidden
 */
var ImageColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ImageColumnDescriptionMetadata, _super);
    function ImageColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImageColumnDescriptionMetadata.b = function (a) {
        if (ImageColumnDescriptionMetadata.a == null) {
            ImageColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImageColumnDescriptionMetadata.c(ImageColumnDescriptionMetadata.a);
        }
        if (a.j(ImageColumnDescriptionMetadata.a)) {
            return;
        }
        a.y(ImageColumnDescriptionMetadata.a);
    };
    ImageColumnDescriptionMetadata.c = function (a) {
        DataGridColumnDescriptionMetadata.c(a);
        a.item("ImageStretchOption", "ExportedType:string:ImageStretchOptions");
        a.item("ImageStretchOption@names", "Uniform;Fill;None");
        a.item("EditorType", "ExportedType:string:EditorType");
        a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
        a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
        a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
        a.item("EditorTextField", "String");
        a.item("EditorValueField", "String");
    };
    ImageColumnDescriptionMetadata.d = function (a) {
        ImageColumnDescriptionMetadata.b(a);
        a.aa("ImageColumn", function () { return new ImageColumnDescription(); });
        a.z("ImageColumn", ImageColumnDescriptionMetadata.a);
    };
    ImageColumnDescriptionMetadata.$t = markType(ImageColumnDescriptionMetadata, 'ImageColumnDescriptionMetadata');
    ImageColumnDescriptionMetadata.a = null;
    return ImageColumnDescriptionMetadata;
}(Base));
export { ImageColumnDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/ImageColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ImageColumnDescription } from "./ImageColumnDescription";
/**
 * @hidden
 */
var ImageColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ImageColumnDescriptionMetadata, _super);
    function ImageColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImageColumnDescriptionMetadata.b = function (a) {
        if (ImageColumnDescriptionMetadata.a == null) {
            ImageColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImageColumnDescriptionMetadata.c(ImageColumnDescriptionMetadata.a);
        }
        if (a.k(ImageColumnDescriptionMetadata.a)) {
            return;
        }
        a.aa(ImageColumnDescriptionMetadata.a);
    };
    ImageColumnDescriptionMetadata.c = function (a) {
        DataGridColumnDescriptionMetadata.c(a);
        a.item("ImageStretchOption", "ExportedType:string:ImageStretchOptions");
        a.item("ImageStretchOption@names", "Uniform;Fill;None");
        a.item("EditorType", "ExportedType:string:EditorType");
        a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
        a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
        a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
        a.item("EditorTextField", "String");
        a.item("EditorValueField", "String");
    };
    ImageColumnDescriptionMetadata.d = function (a) {
        ImageColumnDescriptionMetadata.b(a);
        a.ac("ImageColumn", function () { return new ImageColumnDescription(); });
        a.ab("ImageColumn", ImageColumnDescriptionMetadata.a);
    };
    ImageColumnDescriptionMetadata.$t = markType(ImageColumnDescriptionMetadata, 'ImageColumnDescriptionMetadata');
    ImageColumnDescriptionMetadata.a = null;
    return ImageColumnDescriptionMetadata;
}(Base));
export { ImageColumnDescriptionMetadata };
